<script>
import {Link, useForm} from "@inertiajs/vue3";
import AppLayout from "@/Layouts/AppLayout.vue";
import Modal from "@/Components/Modal.vue";
import Subscription from "@/Pages/Admin/Users/Subscription.vue";
import {MasterMethods} from "@/Store/Functions.js";
import Toast from "@/Componentes/Toastify/Toast.vue";

export default {
    name: "Users",
    components: {Toast, Subscription, Modal, AppLayout,Link},
    data() {
        return {
            modalSubscribed: false,
            customer: null,
            currentPage: 1,
            suspended: useForm({id: 0,page:1}),
            details: false
        }
    },
    watch: {
        modalSubscribed(newVal) {
            if(!newVal) {
                this.customer = null;
            }
        }
    },
    methods: {
        ...MasterMethods,
        closeModal(){
            this.modalSubscribed = false;
        },
        userSuspend(user) {
            this.details = true;
            this.suspended.id = user.id;
            this.suspended.page = this.currentPage;
            this.resetForm(this.suspended)
            this.suspended.delete(route("users.delete"),{
                preserveScroll: true,
                onSuccess: () => {
                    this.suspended.reset()
                },
                onFinish: () => {
                    this.details = false;
                }
            })
        }
    }
}
</script>

<template>
    <Modal :show="modalSubscribed" @close="modalSubscribed=false" maxWidth="sm">
        <Subscription :customer="customer" :currentPage="currentPage" @closeModal="closeModal"  />
    </Modal>
    <Toast :response="suspended" :details="details" />
    <AppLayout title="Usuarios Creados">
        <div class="container">
            <div class="grid grid-cols-2 md:grid-cols-3 lg:grid-cols-5 gap-5">
                <div v-for="user in $page.props?.users.data" class="card card-widget widget-user">
                    <div class="widget-user-header"
                         :class="{'bg-cyan-600':user.role.name === 'Free', 'bg-gray-800':user.role.name === 'Admin', 'bg-green-500':user.role.name === 'VIP'}">
                        <h3 class="widget-user-username text-white text-lg">{{ user.name }}</h3>
                        <h5 class="widget-user-desc text-white">{{ user.role.name}}</h5>
                    </div>
                    <div class="widget-user-image">
                        <img class="img-circle elevation-2" :src="'https://ui-avatars.com/api/?name='+user.name+'&color=FFFFFF&background=0e0e0e'" alt="User Avatar">
                    </div>
                    <div class="card-footer">
                        <div class="grid grid-cols-1">
                            <ul class="nav flex-column">
                                <li class="nav-item">
                                    <a class="nav-link">
                                        Expira <span class="float-right badge">{{ user?.vip_end_date }}</span>
                                    </a>
                                </li>
                                <li class="nav-item">
                                    <a class="nav-link text-center">
                                        <span class="badge">{{ user?.email }}</span>
                                    </a>
                                </li>
                            </ul>
                            <div class="grid grid-cols-2">
                                <button @click="userSuspend(user)" v-if="user?.vip" class="btn bg-red-800 hover:bg-red-700 m-1 text-sm text-white">Cancela</button>
                                <button @click="modalSubscribed=true; customer=user" v-if="user.role_id < 3" class="btn m-1 bg-gray-800 hover:bg-gray-700 text-sm text-white">Actualiza</button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="flex justify-content-center">
                <nav aria-label="...">
                    <ul class="pagination pagination-sm">
                        <li v-for="n in $page.props?.users?.last_page" class="page-item" :class="{active: $page.props?.users?.current_page === n}" aria-current="page">
                            <span v-if="$page.props?.users?.current_page === n" class="page-link">{{n}}</span>
                            <Link v-on:click="currentPage=n" method="post" as="button" :href="route('users.show')" :data="{page: n}" class="page-link" v-else>{{n}}</Link>
                        </li>
                    </ul>
                </nav>
            </div>
        </div>
    </AppLayout>
</template>

<style scoped>

</style>
